@@ -1,6 +1,6 @@
 import datetime
 
-def dateGenerator(self, start_date, end_date, days_frequency):
+def dateGenerator(start_date, end_date, days_frequency):
     """
     Creating a range of dates dependent upon the frequency as set by the user.
 
