@@ -18,7 +18,7 @@ def store():
     """
     pass
 
-def calculate(band_nir, band_red, ground_sampling_distance):
+def calculate(band_red, band_nir, ground_sampling_distance):
     """
     Function for calculating the EVI
     
